Documentation
¶
Index ¶
- Variables
- func DownloadFileSource(downloadPath string, source Source, moduleName string) error
- func DownloadGitSource(downloadPath string, source Source, moduleName string) error
- func DownloadLocalSource(sourcesPath string, source Source, moduleName string) error
- func DownloadSource(recipe *Recipe, source Source, moduleName string) error
- func DownloadTarSource(downloadPath string, source Source, moduleName string) error
- func GetCleanupSuffix(cleanup []string) string
- func GetSourcePath(source Source, moduleName string) string
- func MoveSource(downloadPath string, sourcesPath string, source Source, moduleName string) error
- func MoveSources(downloadPath string, sourcesPath string, sources []Source, moduleName string) error
- func TestArch(onlyArches []string, targetArch string) bool
- type Add
- type Cmd
- type Copy
- type Entrypoint
- type PluginInfo
- type PluginType
- type Recipe
- type Run
- type ScopeData
- type Source
- type Stage
Constants ¶
This section is empty.
Variables ¶
var FS int32 = 16
/ Get a read-only filesystem of the Image
var IMAGEID int32 = 2
/ Get the final tagged Image ID
var IMAGENAME int32 = 1
/ Get the final tagged Image name
var RECIPE int32 = 4
/ Get the build recipe
var RUNTIME int32 = 8
Get the used build runtime
Functions ¶
func DownloadFileSource ¶
Download a file source from a URL and save it to the specified download path. Create necessary directories and handle file naming based on the URL extension.
func DownloadGitSource ¶
Download a Git source repository based on the specified tag, branch, or commit
func DownloadLocalSource ¶
Copies a local source for use during the build, skips the Download directory and copies directly into the source path
func DownloadSource ¶
Download the source based on its type and validate its checksum
func DownloadTarSource ¶
Download a tarball from the specified URL and save it to the destination path
func GetCleanupSuffix ¶
func GetSourcePath ¶
Generate the destination path for the source based on its type and module name
func MoveSource ¶
Move or extract a source from the download path to the sources path depending on its type tarballs: extract git repositories: move
Types ¶
type Entrypoint ¶
Configuration for the entrypoint of a container
type PluginInfo ¶
type PluginInfo struct {
Name string
Type PluginType
UseContainerCmds bool
}
Information about a plugin
type Recipe ¶
type Recipe struct {
Name string
Id string
Vibversion string
Stages []Stage
Path string
ParentPath string
DownloadsPath string
SourcesPath string
IncludesPath string
PluginPath string
Containerfile string
Finalize []interface{}
}
Configuration for a recipe
type Source ¶
type Source struct {
URL string `json:"url"`
Checksum string `json:"checksum"`
Type string `json:"type"`
Commit string `json:"commit"`
Tag string `json:"tag"`
Branch string `json:"branch"`
Packages []string `json:"packages"`
Path string `json:"path"`
OnlyArches []string `json:"only-arches" mapstructure:"only-arches"`
}
Configuration for a source
type Stage ¶
type Stage struct {
Id string `json:"id"`
Base string `json:"base"`
Copy []Copy `json:"copy"`
Addincludes bool `json:"addincludes"`
Labels map[string]string `json:"labels"`
Env map[string]string `json:"env"`
Adds []Add `json:"adds"`
Args map[string]string `json:"args"`
Runs Run `json:"runs"`
Expose map[string]string `json:"expose"`
Cmd Cmd `json:"cmd"`
Modules []interface{} `json:"modules"`
Entrypoint Entrypoint
Cleanup []string `json:"cleanup"`
}
Configuration for a stage in the recipe